#
# spec file for package perl-DBD-ODBC
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with test

Name:           perl-DBD-ODBC
Version:        1.48
Release:        8.11
%define cpan_name DBD-ODBC
Summary:        ODBC Driver for DBI
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/DBD-ODBC/
Source:         http://www.cpan.org/authors/id/M/MJ/MJEVANS/%{cpan_name}-%{version}.tar.gz
Patch0:         %{name}-1.29-Makefile.diff
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  unixODBC-devel
BuildRequires:  perl(DBI) >= 1.609
BuildRequires:  perl(Test::Simple) >= 0.90
Requires:       unixODBC
Requires:       perl(DBI) >= 1.609
%{perl_requires}

%description
This module is needed to access ODBC databases from within Perl. The
module uses the unixODBC manager to connect to the database.

%prep
%setup -q -n %{cpan_name}-%{version}
%patch0
find . -type f -print0 | xargs -0 chmod 644

#rpmlint: wrong-file-end-of-line-encoding
for file in README.af README.unicode; do
  perl -p -i -e "s|\r\n|\n|" "$file"
done

pushd examples
#rpmlint: wrong-file-end-of-line-encoding
find -type f -exec perl -p -i -e "s|\r\n|\n|" {} \;
#rpmlint: wrong-script-interpreter
for ex in $(ls -1); do
  sed -i -e 's,#[!|#]perl\(.*\),#!perl\1,' "$ex"
  sed -i -e 's,perl.exe -w,perl -w,' "$ex"
done
popd

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%clean
rm -rf %{buildroot}

%files -f %{name}.files
%defattr(-,root,root,-)
%doc Changes FAQ if_you_are_taking_over_this_code.txt
%doc README README.adabas README.af README.informix README.sqlserver README.unicode
%doc test_results.txt examples

%changelog
* Tue Jul 22 2014 vcizek@suse.com
- refreshed perl-DBD-ODBC-1.29-Makefile.diff
  (it failed to apply after some of the previous updates)
* Mon Mar 17 2014 coolo@suse.com
- updated to 1.48
  [MISCELLANEOUS]
  Manifest has wrong filename for 90_trace_flags.t
  Forgot to remove warning from ODBC.pm that this is a development
  release and unicode change when I released 1.47.
* Mon Feb 24 2014 coolo@suse.com
- updated to 1.47, see Changes for more
  Full release of the 1.46 development releases.
  [MISCELLANEOUS]
  Just some tidying up of dbdimp.c - shouldn't make a difference to anyone.
  Further changes to this change file to make it CPAN::Changes spec.
  NOTE the changes.cpanhq.com site does not yet support "unknown" for
  dates.
  1.46_2 2013-12-17
  [BUG FIXES]
  When built with unicode support and odbc_old_unicode is not enabled
  columns reported as SQL_LONGVARCHAR were not by default bound as
  SQL_WCHAR and hence were not returned correctly unless the bind was
  overridden.
  [MISCELLANEOUS]
  Added test 90_trace_flag.t
  1.46_1 2013-11-16
  [CHANGE IN BEHAVIOUR]
  As warned in release 1.45, the binding of unicode parameters to
  char/varchar columns has changed significantly. If you don't attempt
  to insert unicode into char/varchar columns or if you only inserted
  unicode into nchar/nvarchar columns you should see no difference.
  From this release, unicode data inserted into
  char/varchar/longvarchar columns is bound as SQL_WCHAR and not
  whatever the driver reports the parameter as (which is mostly
  SQL_CHAR).
  Previously if DBD::ODBC received an error or (SQL_SUCCESS_WITH_INFO)
  from an ODBC API call and then the driver refused to return the
  error state/text DBD::ODBC would issue its own error saying "Unable
  to fetch information about the error" and state IM008. That state
  was wrong and has been changed to HY000.
  [BUG FIXES]
  Some drivers cannot support catalogs and/or schema names in
  SQLTables.  Recent changes set the schema/catalog name to the empty
  string (good reasons below) which causes "optional feature not
  implemented" from MS Access (which does not support schemas - even
  for a simply ping (which uses SQLTables)). Now we call
  SQLCATALOG_NAME and SQLSCHEMA_USAGE on connect to ascertain support
  which modifies SQLTables call.
* Tue Nov 26 2013 coolo@suse.com
- updated to 1.45, see Changes for (a lot of) details
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.43, see Changes (a lot)
* Fri Dec  2 2011 vcizek@suse.com
- update to 1.33
  [ENHANCEMENTS]
  * Enable multiple active statement support in 70execute_array.t for
    drivers we recognise which support MAS.
  * Change column_info to support Unicode catalog/schema/table/column
    names.
  * Use SQLGetTypeInfoW on unicode builds.
  * DBD::ODBC now allows unicode catalog/schema/table parameters to be
    passed to table_info. Of course they will only reliably work with
    a supporting Unicode ODBC driver.
  * Added new odbc_driver_complete attribute allowing the ODBC Driver
    Manager and ODBC Driver to throw dialogues for incomplete
    connection strings or expired passwords etc.
  [BUG FIXES]
  * remove debugging printf which output "HERE" in some rare cases.
    rt 72534 - thanks John Deighan for spotting this.
  * The test 70execute_array.t could fail due to warning being output
    if the driver does not support Multiple Active Statements.
  * Fix bug in utf16_copy which was not adding a trailing NUL but I'm
    not sure this affected anyone until I changed table_info this
    release.
  * I omitted rt_68720.t from the 1.31 distribution which leads
    to a warning as it is mentioned in the MANIFEST.
  [DOCUMENTATION]
  * new FAQ entries
  * added note saying you cannot pass unicode schema/table/column
    names to metadata calls like table_info/column_info currently.
  [OTHER]
  * Changed line endings in README.af and README.unicode to be unix
    line endings and native eol-style in subversion.
  * Minor changes to Makefile.PL to save the opensuse guys patching.
  * Added unicode_sql.pl and unicode_params.pl examples
  * added more examples
* Sat Aug 27 2011 chris@computersalat.de
- fix deps
  * perl(Test::Simple) >= 0.88
  * perl(DBI) >= 1.609
* Fri Jun 24 2011 vcizek@novell.com
- update to 1.31
  [ENHANCEMENTS]
  * An extra argument has been added to the sub associated with
  odbc_err_handler.  The arguments passed to the odbc_err_handler are
  now state (string), error (string), native error code (number) and
  the status returned from the last ODBC API. The status will be
  SQL_ERROR (-1) for errors or SQL_SUCCESS_WITH_INFO (1) for
  informational messages.
  * Added support for StrictlyTyped and DiscardString to the bind_col
    method.
  * Added the new odbc_describe_parameters attribute.
  * added -w option to Makefile.PL to add "-Wall" to CCFLAGS and
  - fno-strict-aliasing so I can find warnings.
  * Cope with broken ODBC drivers that describe a parameter as SQL
    type 0.
* Sat Jun 18 2011 coolo@novell.com
- fix requires of examples
- use original tar
* Wed Mar  9 2011 vcizek@novell.com
- update to 1.29
  * Fixed missing SQL_MAX_TABLE_NAME_LEN definition from test.
  * Fixed problem with some drivers which batch "insert;select" where
    SQLMoreResults is not required and an extra describe is done.
  * Fixed "select 1" in 02simple.t for Firebird ODBC Driver.
  * disconnect call added to 70execute_array.t was in the wrong place.
  * Added support for DBI's new trace flags ENC, CON, TXN and
    DBD.
  * And many other fixes and enhancements
* Fri Jan  7 2011 vcizek@novell.com
- update to 1.27
  Minor fix to head in pod
  rt63550 fix and test code and added pod notes on "do"
  snprintf buffer overflow when GetTypeInfo values are negative
  capture execute error in rt_62033.t
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Sep 23 2010 anicka@suse.cz
- update to 1.25
  * Changed bind_col so it actually pays attention to the TYPE
  attribute as you could not override the bind type of a bound
    column before.
  * Left a sv_undef in
  * Change sprintf to snprintf for safety.
  * Removed some unused fields from the fbh structure which should
  save a little memory for each column in a result-set.
  * Started adding support for DBI's DiscardString and StrictlyTyped
  but not complete yet so don't use them yet.
  * Added experimental odbc_lob_read method - see pod.
  * Moved the binding of columns to the first call to fetch instead of
  after execute is called as it prevents bind_col overrriding the
  type used for binding and I needed it to support odbc_lob_read.
  * Removed support for DBI's blob_read - it was totally flawed and
  did not work at all. May replace in the future.
  * Added support for MS SQL Server XML type (SQL type -152).
  * bugfixes, new FAQs
* Sun Jul 25 2010 chris@computersalat.de
- removed dos2unix usage
* Thu Jun  3 2010 chris@computersalat.de
  update to 1.24
  o please see Changes file
- recreated spec by cpanspec 1.78
- added examples to doc
* Fri Feb 26 2010 anicka@suse.cz
- update to 1.23
  * bugfixes, test fixes
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 1.22
  * bugfixes
* Mon May 18 2009 anicka@suse.cz
- update to 1.21
  * bugfixes, documentation fixes
* Tue Apr 28 2009 anicka@suse.cz
- update to 1.20
  * bugfixes, test fixes
* Mon Apr  6 2009 anicka@suse.cz
- update to 1.19
  * test fixes
* Tue Jan 20 2009 anicka@suse.cz
- update to 1.18
  * bugfixes, test fixes
* Mon Oct  6 2008 anicka@suse.cz
- update to 1.17
  * Changed default fallback parameter bind type to SQL_WVARCHAR for
  unicode builds. This affects ODBC drivers which don't have
  * About a 30%% rewrite of bound parameter code which started with an
  attempt to support the new VARBINARY(MAX) and VARCHAR(MAX)
  columns in SQL Server when the parameter length is > 400K in size
  * Rewrote ColAttributes code to understand string and numeric
  attributes rather than trying to guess by what the driver returns.
  * bugfixes, test fixes
* Fri Jun 27 2008 anicka@suse.cz
- update to 1.16
  * More tracing in dbdimp.c for named parameters.
  * #ifdeffed out odbc_get_primary_keys in dbdimp.c as it is no
  longer used.  $h->func($catalog, $schema, $table, 'GetPrimaryKeys')
  ends up in dbdimp.c/dbd_st_primary_keys now.
  * Changes to Makefile.PL to fix a newly introduced bug with 'tr',
  remove easysoft OOB detection and to try and use odbc_config and
  odbcinst if we find them to aid automatic configuration. This
  latter change also adds "odbc_config --cflags" to the CC line
  when building DBD::ODBC.
  * Added support for parse_trace_flag and parse_trace_flags methods
  and defined a DBD::ODBC private flag 'odbcdev' as a test case.
  * Add support for the 'SQL' trace type. Added private trace type
  odbcdev as an experimental start.
  * Change odbc_query_timeout attribute handling so if it is set to 0
  after having set it to a non-zero value the default of no time
  out is restored.
  * Added support for DBI's statistics_info method.
  * test changes, documentation changes, bugfixes
- remove -uninitialized patch (fixed in upstream)
* Thu Mar 13 2008 anicka@suse.cz
- update to 1.15
  * DBI->connect changed so informational diagnostics like "Changed
  database context to 'master'" from SQL Server are available in
  errstr/state.
  * Changed Makefile.PL to attempt to find unixODBC if -o or ODBCHOME
  not specified.
  * Fairly major changes to dbd_describe in dbdimp.c to reduce ODBC
  calls by 1 SQLDescribeCol call per column when describing result
  sets.
  * Changed to avoid using explicit use of DBIc_ERRXXX in favour
  of newish DBIh_SET_ERR_CHAR.
  * test fixes, bugfixes, documentation added
* Wed Jul 25 2007 anicka@suse.cz
- update to 1.14
  * Add array parameter binding (per new DBI Spec)
  * Add row caching/multiple row fetches to speed selects
  * Better/more tests on multiple statement handles which ensure
    the correct number of rows
  * Better/more tests on all queries which ensure the correct
    number of rows and data
  * Better tests on SQLExecDirect/do
  * Keep checking Oracle's ODBC drivers for Windows to fix
    the Date binding problem
  * Change SQLColAttributes calls (now deprecated)
    to SQLColAttribute
  * Add support for $sth->more_results based on DBD::ODBC-specific
    attribute
  * Removed some unused variable declarations leading to warnings.
  * Removed PerlIO_flush calls as it is believed they are not
    required.
  * Add logging for whether SQLDescribeParam is supported.
  * Add provisional Unicode support. This change is very
    experimental (especially on UNIX). Please see ODBC.pm
    documentation.
  * Updated FAQ, added a few more questions etc.
  * DBD::ODBC requires at least 5.6.0 of Perl.
  * bugfixes, test fixes, documentation fixes
* Fri Feb 16 2007 anicka@suse.cz
- update to 1.13
  * Make ODBC version 3.0 default!
  * Document more of the DBD::ODBC private attributes/functions.
  * Add array parameter binding (per new DBI Spec)
  * Add row caching/multiple row fetches to speed selects
  * Better/more tests on multiple statement handles which ensure
    the correct number of rows
  * Better/more tests on all queries which ensure the correct number
    of rows and data
  * Better tests on SQLExecDirect/do
  * Change default behaviour to use SQLDescribeParam instead of
    SQL_VARCHAR.
  * Fix inconsistency/bug with odbc_exec_direct vs. odbc_execdirect
    settings.
  * Fix handling of print statements for SQL Server.
  * Due to bug in SQL Server, you must use odbc_exec_direct.
  * Change tests to use Test::More.
  * Added odbc_timeout, but untested
  * Added pod.t test, taken from DBI.
  * Change to use dbivport.h per new DBI spec.
  * Add ability to set the cursor type during the connect.
  * many bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct  4 2005 dmueller@suse.de
- add norootforbuild
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 stark@suse.de
- use vendorarch instead of vendorlib
* Thu Jul 17 2003 stark@suse.de
- use new conventions for perl 5.8.1
* Mon Jul  7 2003 stark@suse.de
- update to 1.06
- fixed Makefile.PL
  * add OPTIMIZE
  * fixed usage of $Config{lib_ext}
- workaround for broken generated Makefile
* Thu Jun 19 2003 stark@suse.de
- added DBD directories to filelist
* Mon May 19 2003 stark@suse.de
- removed unwanted files from buildroot
* Tue Apr 22 2003 stark@suse.de
- update to 1.05
* Tue Feb 11 2003 stark@suse.de
- update to 1.04
* Tue Dec 17 2002 stark@suse.de
- update to 1.01
* Wed Nov 27 2002 prehak@suse.cz
- fixed libdir in Makefile.PL
- enabled make test
* Wed Sep 18 2002 stark@suse.de
- initial package
